@@ -6,10 +6,6 @@ from typing import Optional
 
 from nowcasting_dataset.config.model import Configuration
 from nowcasting_dataset.dataset.batch import Batch
-from nowcasting_dataset.dataset.xr_utils import (
-    register_xr_data_array_to_tensor,
-    register_xr_data_set_to_tensor,
-)
 from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import BaseModel, Field
 
@@ -23,6 +19,10 @@ from nowcasting_dataloader.data_sources import (
     SunML,
     TopographicML,
 )
+from nowcasting_dataloader.xr_utils import (
+    register_xr_data_array_to_tensor,
+    register_xr_data_set_to_tensor,
+)
 
 _LOG = logging.getLogger(__name__)
 
@@ -84,10 +84,14 @@ class BatchML(Example):
         process = configuration.process
         input_data = configuration.input_data
 
+        seq_length_30 = int(
+            (input_data.default_history_minutes + input_data.default_forecast_minutes) / 30 + 1
+        )
+
         t0_dt, time_5, time_30 = make_random_time_vectors(
             batch_size=process.batch_size,
             seq_length_5_minutes=input_data.default_seq_length_5_minutes,
-            seq_length_30_minutes=input_data.default_seq_length_5_minutes // 6,
+            seq_length_30_minutes=seq_length_30,
         )
 
         return BatchML(
@@ -112,7 +116,7 @@ class BatchML(Example):
             ),
             gsp=GSPML.fake(
                 process.batch_size,
-                seq_length_30=input_data.default_seq_length_5_minutes // 6,
+                seq_length_30=seq_length_30,
                 n_gsp_per_batch=32,
                 time_30=time_30,
             ),
