@@ -9,6 +9,7 @@ from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import Field
 
 from nowcasting_dataloader.data_sources.datasource_output import Array, DataSourceOutputML
+from nowcasting_dataloader.utils.dims import re_order_dims
 
 logger = logging.getLogger(__name__)
 
@@ -90,10 +91,10 @@ class SatelliteML(DataSourceOutputML):
             batch_size=batch_size,
             data=np.random.randn(
                 batch_size,
+                number_sat_channels,
                 seq_length_5,
                 satellite_image_size_pixels,
                 satellite_image_size_pixels,
-                number_sat_channels,
             ).astype(np.float32),
             x=np.sort(np.random.randn(batch_size, satellite_image_size_pixels)),
             y=np.sort(np.random.randn(batch_size, satellite_image_size_pixels))[:, ::-1].copy()
@@ -113,8 +114,13 @@ class SatelliteML(DataSourceOutputML):
     def from_xr_dataset(xr_dataset: xr.Dataset):
         """Change xr dataset to model."""
 
+        # make sure the dims are in the correct order
+        xr_dataset = re_order_dims(xr_dataset)
+
+        # convert to torch dictionary
         satellite_batch_ml = xr_dataset.torch.to_tensor(["data", "time", "x", "y", "channels"])
 
+        # move to Modle
         return SatelliteML(**satellite_batch_ml)
 
     def normalize(self):
